pyxmpp2.mainloop

Package pyxmpp2 :: Package mainloop |
[hide private]

# Package mainloop

PyXMPP main event loop - the event and I/O framework, aka re-inventing the wheel.

Submodules | [hide private]
pyxmpp2.mainloop.base: Main loop implementation Base. pyxmpp2.mainloop.events: PyXMPP events. pyxmpp2.mainloop.interfaces: Abstract base classes for the main loop framework. pyxmpp2.mainloop.poll: I/O Handling classes pyxmpp2.mainloop.select: I/O Handling classes pyxmpp2.mainloop.threads: I/O Handling classes pyxmpp2.mainloop.wait: Utility functions to wait until a socket (or object implementing .fileno() in POSIX) is ready for input or output.